DP Analysis

Install:
(1) Direct download from github https://github.com/taipinghu/DPAnalysis.git or git clone git@github.com:taipinghu/DPAnalysis.git
(2) Add the dir path to the PYTHONPATH and PATH.



